@@ -180,13 +180,13 @@ extends 'Pod::Readme::Filter';
 
 {
     use version 0.77;
-    $Pod::Readme::VERSION = version->declare('v1.0.1_02');
+    $Pod::Readme::VERSION = version->declare('v1.0.1_03');
 }
 
 use Carp;
 use IO qw/ File Handle /;
 use Module::Load qw/ load /;
-use Path::Class;
+use Path::Tiny qw/ path tempfile /;
 use Types::Standard qw/ Maybe Str /;
 
 use Pod::Readme::Types qw/ File WriteIO /;
@@ -245,7 +245,7 @@ sub _build_translate_to_fh {
 
 =head2 C<translate_to_file>
 
-The L<Path::Class::File> to save the translated file to. If omitted,
+The L<Path::Tiny::File> to save the translated file to. If omitted,
 then it will be saved to C<STDOUT>.
 
 =cut
@@ -267,10 +267,7 @@ file.
 
 has '+output_file' => (
     lazy    => 1,
-    default => sub {
-        my $tmp_dir = dir( $ENV{TMP} || $ENV{TEMP} || '/tmp' );
-        file( ( $tmp_dir->tempfile( SUFFIX => '.pod', UNLINK => 1 ) )[1] );
-    },
+    default => sub { tempfile( SUFFIX => '.pod', UNLINK => 1 ); },
 );
 
 around '_build_output_fh' => sub {
@@ -319,7 +316,7 @@ sub default_readme_file {
         $name .= '.pod';
     }
 
-    file( $self->base_dir, $name );
+    path( $self->base_dir, $name );
 }
 
 =head2 C<translate_file>
@@ -450,6 +447,11 @@ The original version was by Robert Rothenberg <rrwo@cpan.org> until
 In 2014, Robert Rothenberg rewrote the module to use filtering instead
 of subclassing a POD parser.
 
+=head2 Acknowledgements
+
+Thanks to people who gave feedback and suggestions to posts about the
+rewrite of this module on L<http://blogs.perl.org>.
+
 =head2 Suggestions, Bug Reporting and Contributing
 
 This module is developed on GitHub at
